# Custom Fact Sheet Types
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types#overview)
  * [Best Practices](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types#best-practices)
  * [Creating a Custom Fact Sheet Type](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types#creating-a-custom-fact-sheet-type)
  * [Deleting a Custom Fact Sheet Type](https://help.sap.com/docs/leanix/ea/custom-fact-sheet-types#deleting-a-custom-fact-sheet-type)


Create custom fact sheet types to adjust the meta model to your organization’s needs.
